@@ -1,6 +1,6 @@
 # pylint:disable=invalid-name, cyclic-import
 """
-The tool to check the availability or syntax of domains, IPv4, IPv6 or URL.
+The tool to check the availability or syntax of domain, IP or URL.
 
 ::
 
@@ -25,7 +25,7 @@ Project link:
     https://github.com/funilrys/PyFunceble
 
 Project documentation:
-    https://pyfunceble.readthedocs.io///en/master/
+    https://pyfunceble.readthedocs.io/en/master/
 
 Project homepage:
     https://pyfunceble.github.io/
@@ -34,27 +34,19 @@ License:
 ::
 
 
-    MIT License
+    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
 
-    Copyright (c) 2017, 2018, 2019, 2020 Nissar Chababy
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
 
-    Permission is hereby granted, free of charge, to any person obtaining a copy
-    of this software and associated documentation files (the "Software"), to deal
-    in the Software without restriction, including without limitation the rights
-    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-    copies of the Software, and to permit persons to whom the Software is
-    furnished to do so, subject to the following conditions:
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    The above copyright notice and this permission notice shall be included in all
-    copies or substantial portions of the Software.
-
-    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-    SOFTWARE.
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
 """
 
 import warnings
@@ -86,6 +78,8 @@ NAME = abstracts.Package.NAME
 # We set out project version.
 VERSION = abstracts.Package.VERSION
 
+load_dotenv(".env")
+load_dotenv(abstracts.Infrastructure.ENV_FILENAME)
 
 if helpers.EnvironmentVariable("PYFUNCEBLE_CONFIG_DIR").exists():  # pragma: no cover
     # We handle the case that the `PYFUNCEBLE_CONFIG_DIR` environnement variable is set.
@@ -169,9 +163,25 @@ if not CONFIG_DIRECTORY.endswith(directory_separator):  # pragma: no cover
     # the directory separator, we append it to the end.
     CONFIG_DIRECTORY += directory_separator
 
-# We set the location of the `output` directory which should always be in the current
-# directory.
-OUTPUT_DIRECTORY = helpers.Directory.get_current(with_end_sep=True)
+load_dotenv(CONFIG_DIRECTORY + ".env")
+load_dotenv(CONFIG_DIRECTORY + abstracts.Infrastructure.ENV_FILENAME)
+
+if helpers.EnvironmentVariable(
+    "PYFUNCEBLE_OUTPUT_LOCATION"
+).exists():  # pragma: no cover
+    # We set the location of the `output/` directory.
+    OUTPUT_DIRECTORY = helpers.EnvironmentVariable(
+        "PYFUNCEBLE_OUTPUT_LOCATION"
+    ).get_value()
+else:  # pragma: no cover
+    # We set the location of the `output` directory which should always be in the current
+    # directory.
+    OUTPUT_DIRECTORY = helpers.Directory.get_current(with_end_sep=True)
+
+if not OUTPUT_DIRECTORY.endswith(directory_separator):  # pragma: no cover
+    # Again for safety, if the directory we are working with does not ends with
+    # the directory separator, we append it to the end.
+    OUTPUT_DIRECTORY += directory_separator
 
 # We initiate the location where we are going to save our whole configuration content.
 CONFIGURATION = None
@@ -199,10 +209,6 @@ IANALOOKUP = None
 # We initate the loader.
 LOADER = None
 
-load_dotenv()
-load_dotenv(CONFIG_DIRECTORY + ".env")
-load_dotenv(CONFIG_DIRECTORY + abstracts.Infrastructure.ENV_FILENAME)
-
 # We initiate the CLI logo of PyFunceble.
 ASCII_PYFUNCEBLE = """
 ██████╗ ██╗   ██╗███████╗██╗   ██╗███╗   ██╗ ██████╗███████╗██████╗ ██╗     ███████╗
