@@ -1,6 +1,6 @@
 # pylint: disable=too-many-lines, line-too-long
 """
-The tool to check the availability or syntax of domains, IPv4, IPv6 or URL.
+The tool to check the availability or syntax of domain, IP or URL.
 
 ::
 
@@ -27,7 +27,7 @@ Project link:
     https://github.com/funilrys/PyFunceble
 
 Project documentation:
-    https://pyfunceble.readthedocs.io///en/master/
+    https://pyfunceble.readthedocs.io/en/master/
 
 Project homepage:
     https://pyfunceble.github.io/
@@ -36,27 +36,19 @@ License:
 ::
 
 
-    MIT License
+    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
 
-    Copyright (c) 2017, 2018, 2019, 2020 Nissar Chababy
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
 
-    Permission is hereby granted, free of charge, to any person obtaining a copy
-    of this software and associated documentation files (the "Software"), to deal
-    in the Software without restriction, including without limitation the rights
-    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-    copies of the Software, and to permit persons to whom the Software is
-    furnished to do so, subject to the following conditions:
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    The above copyright notice and this permission notice shall be included in all
-    copies or substantial portions of the Software.
-
-    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-    SOFTWARE.
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
 """
 
 import argparse
@@ -100,12 +92,12 @@ def tool():  # pragma: no cover pylint: disable=too-many-branches,too-many-state
 
                 description = (
                     f"{Style.BRIGHT}{Fore.GREEN}PyFunceble{Style.RESET_ALL} - "
-                    "The tool to check the availability or syntax of domains, IPv4, IPv6 or URL."
+                    "The tool to check the availability or syntax of domain, IP or URL."
                 )
 
                 epilog = (
                     f"{Style.BRIGHT}{Fore.YELLOW}For an in-depth usage, explanation and examples of the arguments, "
-                    f"you should read the documentation at{Fore.GREEN} https://pyfunceble.readthedocs.io///en/master/"
+                    f"you should read the documentation at{Fore.GREEN} https://pyfunceble.readthedocs.io/en/master/"
                     f"{Style.RESET_ALL}\n\n"
                     f"Crafted with {Fore.RED}♥{Fore.RESET} by "
                     f"{Style.BRIGHT}{Fore.CYAN}Nissar Chababy (@funilrys){Style.RESET_ALL} "
@@ -143,7 +135,8 @@ def tool():  # pragma: no cover pylint: disable=too-many-branches,too-many-state
                     "--domain",
                     type=str,
                     nargs="+",
-                    help="Test one or more domains, separated by spaces.",
+                    help="Test one or more domains, separated by spaces.\n\n"
+                    "When this option is used, no output files are generated.",
                 )
 
                 source_group.add_argument(
@@ -299,6 +292,32 @@ def tool():  # pragma: no cover pylint: disable=too-many-branches,too-many-state
                     ),
                 )
 
+                test_control.add_argument(
+                    "--reputation",
+                    action="store_true",
+                    help="Switch the value of the reputation test mode. %s"
+                    % (
+                        current_value_format
+                        + repr(PyFunceble.CONFIGURATION.reputation)
+                        + Style.RESET_ALL
+                    ),
+                )
+
+                test_control.add_argument(
+                    "--shadow-file",
+                    "--shadow",
+                    action="store_true",
+                    help="Switch the value of the usage and generation of a shadow file "
+                    "before a file test starts.\n\nA shadow file is a file which only "
+                    "contain the actual list of subject to test. For its generation we check each "
+                    "subjects as we normally do on-the-fly. %s"
+                    % (
+                        current_value_format
+                        + repr(PyFunceble.CONFIGURATION.shadow_file)
+                        + Style.RESET_ALL
+                    ),
+                )
+
                 test_control.add_argument(
                     "--syntax",
                     action="store_true",
@@ -315,7 +334,7 @@ def tool():  # pragma: no cover pylint: disable=too-many-branches,too-many-state
                     "--timeout",
                     type=float,
                     default=0,
-                    help="Switch the value of the timeout. %s"
+                    help="Switch the value of the timeout in seconds. %s"
                     % (
                         current_value_format
                         + repr(PyFunceble.CONFIGURATION.timeout)
@@ -323,17 +342,6 @@ def tool():  # pragma: no cover pylint: disable=too-many-branches,too-many-state
                     ),
                 )
 
-                test_control.add_argument(
-                    "--reputation",
-                    action="store_true",
-                    help="Switch the value of the reputation test mode. %s"
-                    % (
-                        current_value_format
-                        + repr(PyFunceble.CONFIGURATION.reputation)
-                        + Style.RESET_ALL
-                    ),
-                )
-
                 test_control.add_argument(
                     "--use-reputation-data",
                     action="store_true",
@@ -1073,6 +1081,9 @@ def tool():  # pragma: no cover pylint: disable=too-many-branches,too-many-state
                 if args.reputation:
                     PyFunceble.CONFIGURATION.reputation = preset.switch("reputation")
 
+                if args.shadow_file:
+                    PyFunceble.CONFIGURATION.shadow_file = preset.switch("shadow_file")
+
                 if args.share_logs:
                     PyFunceble.CONFIGURATION.share_logs = preset.switch("share_logs")
 
