@@ -1,5 +1,5 @@
 """
-The tool to check the availability or syntax of domains, IPv4, IPv6 or URL.
+The tool to check the availability or syntax of domain, IP or URL.
 
 ::
 
@@ -26,7 +26,7 @@ Project link:
     https://github.com/funilrys/PyFunceble
 
 Project documentation:
-    https://pyfunceble.readthedocs.io///en/master/
+    https://pyfunceble.readthedocs.io/en/master/
 
 Project homepage:
     https://pyfunceble.github.io/
@@ -34,28 +34,19 @@ Project homepage:
 License:
 ::
 
+    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
 
-    MIT License
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
 
-    Copyright (c) 2017, 2018, 2019, 2020 Nissar Chababy
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    Permission is hereby granted, free of charge, to any person obtaining a copy
-    of this software and associated documentation files (the "Software"), to deal
-    in the Software without restriction, including without limitation the rights
-    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-    copies of the Software, and to permit persons to whom the Software is
-    furnished to do so, subject to the following conditions:
-
-    The above copyright notice and this permission notice shall be included in all
-    copies or substantial portions of the Software.
-
-    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-    SOFTWARE.
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
 """
 
 from tempfile import NamedTemporaryFile
@@ -278,7 +269,7 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
                 ).get()
             else:
                 result = PyFunceble.status.DomainAndIpSyntax(
-                    subject,
+                    subject.lower(),
                     whois_db=self.whois_db,
                     inactive_db=self.inactive_db,
                     filename=self.file,
@@ -293,7 +284,7 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
                 ).get()
             else:
                 result = PyFunceble.status.DomainAndIPReputation(
-                    subject,
+                    subject.lower(),
                     whois_db=self.whois_db,
                     inactive_db=self.inactive_db,
                     filename=self.file,
@@ -307,7 +298,7 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
             ).get()
         else:
             result = PyFunceble.status.DomainAndIpAvailability(
-                subject,
+                subject.lower(),
                 whois_db=self.whois_db,
                 inactive_db=self.inactive_db,
                 filename=self.file,
@@ -521,6 +512,8 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
         else:
             subjects = PyFunceble.converter.File(line).get_converted()
 
+        if isinstance(subjects, str):
+            return [subjects]
         return subjects
 
     def __test_line(self, line, ignore_inactive_db_check=False):
@@ -540,6 +533,63 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
                 subjects, ignore_inactive_db_check=ignore_inactive_db_check
             )
 
+    def write_in_shadow_file_if_needed(
+        self,
+        line,
+        temp_file,
+        ignore_inactive_db_check=False,
+        autocontinue=None,
+        inactive_db=None,
+    ):
+        """
+        Checks if the given line should be in the
+        shadow file.
+        """
+
+        subjects = self.get_subjects(line)
+
+        if autocontinue is None:
+            autocontinue = self.autocontinue
+        if inactive_db is None:
+            inactive_db = self.inactive_db
+
+        if isinstance(subjects, list):
+            comparison = [
+                self.should_be_ignored(
+                    x,
+                    auto_continue_db=autocontinue,
+                    inactive_db=inactive_db,
+                    ignore_inactive_db_check=ignore_inactive_db_check,
+                )
+                for x in subjects
+            ]
+        else:
+            comparison = [
+                self.should_be_ignored(
+                    subjects,
+                    auto_continue_db=autocontinue,
+                    inactive_db=inactive_db,
+                    ignore_inactive_db_check=ignore_inactive_db_check,
+                )
+            ]
+
+        if all(comparison) and (
+            self.autosave.authorized or PyFunceble.CONFIGURATION.print_dots
+        ):
+            print("I", end="")
+        elif self.autosave.authorized or PyFunceble.CONFIGURATION.print_dots:
+            print("S", end="")
+
+        if not all(comparison):
+            to_write = (
+                "\n".join([subjects[x] for x, _ in enumerate(comparison) if comparison])
+                + "\n"
+            )
+
+            if isinstance(temp_file, str):
+                temp_file = open(temp_file, "a+b")
+            temp_file.write(to_write.encode("utf-8"))
+
     def construct_and_get_shadow_file(
         self, file_stream, ignore_inactive_db_check=False
     ):
@@ -550,48 +600,23 @@ class FileCore(CLICore):  # pylint: disable=too-many-instance-attributes
         and what we still have to test.
         """
 
-        with NamedTemporaryFile(delete=False) as temp_file:
-            if self.autosave.authorized or PyFunceble.CONFIGURATION.print_dots:
-                print("")
+        if PyFunceble.CONFIGURATION.shadow_file:
+            with NamedTemporaryFile(delete=False) as temp_file:
+                if self.autosave.authorized or PyFunceble.CONFIGURATION.print_dots:
+                    print("")
 
-            for line in file_stream:
-                subjects = self.get_subjects(line)
-
-                if isinstance(subjects, list):
-                    comparison = [
-                        self.should_be_ignored(
-                            x,
-                            auto_continue_db=self.autocontinue,
-                            inactive_db=self.inactive_db,
-                            ignore_inactive_db_check=ignore_inactive_db_check,
-                        )
-                        for x in subjects
-                    ]
-                else:
-                    comparison = [
-                        self.should_be_ignored(
-                            subjects,
-                            auto_continue_db=self.autocontinue,
-                            inactive_db=self.inactive_db,
-                            ignore_inactive_db_check=ignore_inactive_db_check,
-                        )
-                    ]
-
-                if all(comparison):
-                    if self.autosave.authorized or PyFunceble.CONFIGURATION.print_dots:
-                        print("I", end="")
-
-                    continue
+                for line in file_stream:
+                    self.write_in_shadow_file_if_needed(
+                        line,
+                        temp_file,
+                        ignore_inactive_db_check=ignore_inactive_db_check,
+                    )
 
                 if self.autosave.authorized or PyFunceble.CONFIGURATION.print_dots:
-                    print("S", end="")
+                    print("")
 
-                temp_file.write(line.encode("utf-8"))
-
-            if self.autosave.authorized or PyFunceble.CONFIGURATION.print_dots:
-                print("")
-
-            return temp_file.name
+                return temp_file.name
+        return file_stream.name
 
     def run_test(self):
         """
