@@ -1,5 +1,5 @@
 """
-The tool to check the availability or syntax of domains, IPv4, IPv6 or URL.
+The tool to check the availability or syntax of domain, IP or URL.
 
 ::
 
@@ -26,7 +26,7 @@ Project link:
     https://github.com/funilrys/PyFunceble
 
 Project documentation:
-    https://pyfunceble.readthedocs.io///en/master/
+    https://pyfunceble.readthedocs.io/en/master/
 
 Project homepage:
     https://pyfunceble.github.io/
@@ -35,32 +35,25 @@ License:
 ::
 
 
-    MIT License
+    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
 
-    Copyright (c) 2017, 2018, 2019, 2020 Nissar Chababy
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
 
-    Permission is hereby granted, free of charge, to any person obtaining a copy
-    of this software and associated documentation files (the "Software"), to deal
-    in the Software without restriction, including without limitation the rights
-    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-    copies of the Software, and to permit persons to whom the Software is
-    furnished to do so, subject to the following conditions:
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    The above copyright notice and this permission notice shall be included in all
-    copies or substantial portions of the Software.
-
-    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-    SOFTWARE.
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
 """
 
 import sys
 from itertools import chain
 from multiprocessing import Manager, Pipe, Process, active_children
+from tempfile import NamedTemporaryFile
 from traceback import format_exc
 
 from colorama import Fore, Style
@@ -187,6 +180,9 @@ class MultiprocessCore(
             if isinstance(PyFunceble.CONFIGURATION.cooldown_time, (float, int)):
                 PyFunceble.sleep(PyFunceble.CONFIGURATION.cooldown_time)
 
+            if file_content_type in ["domain"]:
+                subject = subject.lower()
+
             if PyFunceble.CONFIGURATION.syntax:
                 result = APICore(
                     subject, complete=True, is_parent=False, db_file_name=self.file
@@ -228,6 +224,7 @@ class MultiprocessCore(
             if (
                 not self.autosave.authorized
                 and PyFunceble.CONFIGURATION.multiprocess_merging_mode != "live"
+                and not PyFunceble.CONFIGURATION.quiet
             ):
                 print(
                     Fore.MAGENTA
@@ -419,6 +416,93 @@ class MultiprocessCore(
                 self.__merge_processes_data(manager_data)
                 break
 
+    def work_process(self, *args):
+        """
+        Work process for :code`construct_and_get_shadow_file`.
+        """
+
+        PyFunceble.LOADER = args[-2]
+
+        if not PyFunceble.LOADER.was_configuration_loaded():
+            PyFunceble.LOADER.get_config()
+
+        PyFunceble.LOADER.inject_all()
+
+        PyFunceble.INTERN.update(args[-1])
+
+        self.write_in_shadow_file_if_needed(*args[:-2])
+
+    def construct_and_get_shadow_file(
+        self, file_stream, ignore_inactive_db_check=False
+    ):
+        """
+        Provides a path to a file which contain the list to file.
+
+        The idea is to do a comparison between what we already tested
+        and what we still have to test.
+        """
+
+        def start_process(*args):
+
+            original_config = PyFunceble.CONFIGURATION.copy()
+            origin_intern = PyFunceble.INTERN.copy()
+
+            args += (PyFunceble.LOADER,)
+            args += (origin_intern,)
+
+            process = OurProcessWrapper(target=self.work_process, args=args)
+            process.name = f"PyF shadow {line}"
+            process.start()
+
+            PyFunceble.LOADER.config.update(original_config)
+            PyFunceble.LOADER.inject_all()
+            PyFunceble.INTERN.update(origin_intern)
+
+        if PyFunceble.CONFIGURATION.shadow_file:
+            with NamedTemporaryFile(delete=False) as temp_file:
+                if self.autosave.authorized or PyFunceble.CONFIGURATION.print_dots:
+                    print("")
+
+                finished = False
+
+                while True:
+                    while (
+                        len(active_children())
+                        <= PyFunceble.CONFIGURATION.maximal_processes
+                    ):
+                        try:
+                            line = next(file_stream)
+
+                            start_process(
+                                line,
+                                temp_file.name,
+                                ignore_inactive_db_check,
+                                self.autocontinue,
+                                self.inactive_db,
+                            )
+
+                            active_children()
+                            continue
+                        except StopIteration:
+                            finished = True
+                            break
+
+                    while len(
+                        active_children()
+                    ) >= PyFunceble.CONFIGURATION.maximal_processes and "shadow" in " ".join(
+                        [x.name for x in reversed(active_children())]
+                    ):
+                        active_children()
+
+                    if finished:
+                        break
+
+                if self.autosave.authorized or PyFunceble.CONFIGURATION.print_dots:
+                    print("")
+
+                return temp_file.name
+        return file_stream.name
+
     def run_test(self):
         """
         Runs the test of the content of the given file.
