@@ -1,5 +1,5 @@
 """
-The tool to check the availability or syntax of domains, IPv4, IPv6 or URL.
+The tool to check the availability or syntax of domain, IP or URL.
 
 ::
 
@@ -26,7 +26,7 @@ Project link:
     https://github.com/funilrys/PyFunceble
 
 Project documentation:
-    https://pyfunceble.readthedocs.io///en/master/
+    https://pyfunceble.readthedocs.io/en/master/
 
 Project homepage:
     https://pyfunceble.github.io/
@@ -35,27 +35,19 @@ License:
 ::
 
 
-    MIT License
+    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
 
-    Copyright (c) 2017, 2018, 2019, 2020 Nissar Chababy
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
 
-    Permission is hereby granted, free of charge, to any person obtaining a copy
-    of this software and associated documentation files (the "Software"), to deal
-    in the Software without restriction, including without limitation the rights
-    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-    copies of the Software, and to permit persons to whom the Software is
-    furnished to do so, subject to the following conditions:
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    The above copyright notice and this permission notice shall be included in all
-    copies or substantial portions of the Software.
-
-    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-    SOFTWARE.
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
 """
 
 
@@ -211,10 +203,10 @@ class AutoContinue:  # pylint: disable=too-many-instance-attributes
                     self.filename not in self.database
                     or not self.database[self.filename]
                 ):
-                    PyFunceble.LOGGER.info(f"File to test was not previously indexed.")
+                    PyFunceble.LOGGER.info("File to test was not previously indexed.")
                     return True
 
-                PyFunceble.LOGGER.info(f"File to test was previously indexed.")
+                PyFunceble.LOGGER.info("File to test was previously indexed.")
                 return False
 
             if PyFunceble.CONFIGURATION.db_type in ["mariadb", "mysql"]:
@@ -228,14 +220,14 @@ class AutoContinue:  # pylint: disable=too-many-instance-attributes
                     fetched = cursor.fetchone()
 
                 if fetched["COUNT(*)"] == 0:
-                    PyFunceble.LOGGER.info(f"File to test was not previously indexed.")
+                    PyFunceble.LOGGER.info("File to test was not previously indexed.")
                     return True
 
-                PyFunceble.LOGGER.info(f"File to test was previously indexed.")
+                PyFunceble.LOGGER.info("File to test was previously indexed.")
                 return False
 
         PyFunceble.LOGGER.info(  # pragma: no cover
-            f"Could not check if the file to test "
+            "Could not check if the file to test "
             "was previously indexed. Unauthorized action."
         )
         return False  # pragma: no cover
