@@ -1,6 +1,6 @@
 # pylint:disable=line-too-long
 """
-The tool to check the availability or syntax of domains, IPv4, IPv6 or URL.
+The tool to check the availability or syntax of domain, IP or URL.
 
 ::
 
@@ -27,7 +27,7 @@ Project link:
     https://github.com/funilrys/PyFunceble
 
 Project documentation:
-    https://pyfunceble.readthedocs.io///en/master/
+    https://pyfunceble.readthedocs.io/en/master/
 
 Project homepage:
     https://pyfunceble.github.io/
@@ -36,27 +36,19 @@ License:
 ::
 
 
-    MIT License
+    Copyright 2017, 2018, 2019, 2020 Nissar Chababy
 
-    Copyright (c) 2017, 2018, 2019, 2020 Nissar Chababy
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
 
-    Permission is hereby granted, free of charge, to any person obtaining a copy
-    of this software and associated documentation files (the "Software"), to deal
-    in the Software without restriction, including without limitation the rights
-    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-    copies of the Software, and to permit persons to whom the Software is
-    furnished to do so, subject to the following conditions:
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    The above copyright notice and this permission notice shall be included in all
-    copies or substantial portions of the Software.
-
-    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-    SOFTWARE.
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
 """
 # pylint: enable=line-too-long
 # pylint: disable=import-error
@@ -134,6 +126,8 @@ class TestCheck(TestCase):
             "xn--cryptopi-ux0d.com",
             "xn--cyptopia-4e0d.com.",
             "xn--cyptopia-4e0d.com",
+            "www.hello_world.blogspot.co.nz",
+            "hello_world.blogspot.co.nz",
         ]
 
         self.not_valid_domain = [
@@ -165,6 +159,7 @@ class TestCheck(TestCase):
             "world-hello",
             "world.hello:80",
             "world@hello.com",
+            "hello_world.co.za",
         ]
 
     def test_is_url(self):
@@ -179,7 +174,7 @@ class TestCheck(TestCase):
 
             actual = Check(to_test).is_url()
 
-            self.assertEqual(expected, actual)
+            self.assertEqual(expected, actual, to_test)
 
             to_test = "http://{0}:8080/helloworld".format(domain)
 
@@ -226,7 +221,7 @@ class TestCheck(TestCase):
 
             actual = Check(to_check).is_url(return_base=True)
 
-            self.assertEqual(expected, actual)
+            self.assertEqual(expected, actual, to_check)
 
     def test_is_url_get_not_base(self):
         """
